@@ -1,9 +1,8 @@
 test_that("local mod object", {
-  testInitOut <- testInit(smcc = FALSE, debug = FALSE,
+  testInit(smcc = FALSE, debug = FALSE, verbose = TRUE,
                           opts = list("reproducible.useMemoise" = FALSE))
-  on.exit({
-    testOnExit(testInitOut)
-  }, add = TRUE)
+  opts <- options(reproducible.cachePath = tmpCache)
+  on.exit(options(opts), add = TRUE)
 
   newModule("test", tmpdir, open = FALSE)
   newModule("test2", tmpdir, open = FALSE)
@@ -11,140 +10,9 @@ test_that("local mod object", {
   test2FilePath <- file.path(tmpdir, "test2", "test2.R")
 
   # Sept 18 2018 -- Changed to use "seconds" -- better comparison with simple loop
-  cat(file = testFilePath,'
-      defineModule(sim, list(
-      name = "test",
-      description = "insert module description here",
-      keywords = c("insert key words here"),
-      authors = person(c("Eliot", "J", "B"), "McIntire", email = "eliot.mcintire@canada.ca", role = c("aut", "cre")),
-      childModules = character(0),
-      version = list(SpaDES.core = "0.1.0", test = "0.0.1"),
-      spatialExtent = raster::extent(rep(NA_real_, 4)),
-      timeframe = as.POSIXlt(c(NA, NA)),
-      timeunit = "second",
-      citation = list("citation.bib"),
-      documentation = list("README.md", "test.Rmd"),
-      reqdPkgs = list(),
-      parameters = rbind(
-        defineParameter("testParA", "numeric", 1, NA, NA, "")
-      ),
-      inputObjects = bindrows(
-        expectsInput("sdf", "sdf", "sdfd")
-      ),
-      outputObjects = bindrows(
-        createsOutput("testPar1", "numeric", "")
-      )
-      ))
+  cat(file = testFilePath, testCode, fill = TRUE)
 
-      doEvent.test = function(sim, eventTime, eventType, debug = FALSE) {
-      switch(
-      eventType,
-      init = {
-      mod$a <- 2
-      sim$testPar1 <- Par$testParA
-
-      if (tryCatch(exists("Init", envir = asNamespace("test"), inherits = FALSE), error = function(x) FALSE)) {
-        sim <- Init(sim)
-      }
-
-      sim <- scheduleEvent(sim, sim@simtimes[["current"]] + 1, "test", "event1", .skipChecks = TRUE)
-      },
-      event1 = {
-      sim <- scheduleEvent(sim, sim@simtimes[["current"]] + 1, "test", "event1", .skipChecks = TRUE)
-      })
-      return(invisible(sim))
-      }
-
-      .inputObjects <- function(sim) {
-        mod$x <- "sdf"
-        return(sim)
-
-      }
-      ', fill = TRUE)
-
-  cat(file = test2FilePath,'
-      defineModule(sim, list(
-      name = "test2",
-      description = "insert module description here",
-      keywords = c("insert key words here"),
-      authors = person(c("Eliot", "J", "B"), "McIntire", email = "eliot.mcintire@canada.ca", role = c("aut", "cre")),
-      childModules = character(0),
-      version = list(SpaDES.core = "0.1.0", test2 = "0.0.1"),
-      spatialExtent = raster::extent(rep(NA_real_, 4)),
-      timeframe = as.POSIXlt(c(NA, NA)),
-      timeunit = "second",
-      citation = list("citation.bib"),
-      documentation = list("README.md", "test2.Rmd"),
-      reqdPkgs = list(),
-      parameters = rbind(
-        defineParameter("testParB", "numeric", 2, NA, NA, ""),
-        defineParameter("testParC", "numeric", 22, NA, NA, ""),
-        defineParameter("testParD", "numeric", 12, NA, NA, "")
-      ),
-      inputObjects = bindrows(
-        expectsInput("sdf", "sdf", "sdfd")
-      ),
-      outputObjects = bindrows(
-        createsOutput("testPar2", "numeric", "")
-      )
-      ))
-
-      doEvent.test2 = function(sim, eventTime, eventType, debug = FALSE) {
-      P(sim)$testParF <- 77
-      P(sim)$testParA <- 42
-      P(sim, "testParG") <- 79
-      P(sim, "testParH") <- 48
-      switch(
-      eventType,
-      init = {
-      if (tryCatch(exists("Init", envir = asNamespace("test2"), inherits = FALSE), error = function(x) FALSE)) {
-        sim <- Init(sim)
-      }
-
-      if (isTRUE(P(sim)$testParB >= 1100)) {
-         P(sim, "testParB") <-  P(sim)$testParB + 756
-      }
-
-      if (any(grepl("testCommonPar", names(unlist(params(sim)))))) {
-            errorText <- try(paramCheckOtherMods(sim, "testCommonPar"), silent = TRUE)
-            if (identical("try-error", attr(errorText, "class")))
-              message("There was an error")
-            warn <- capture_warnings(paramCheckOtherMods(sim, "testCommonPar", ifSetButDifferent = "warning"))
-            if (length(warn))
-              message("There was a warning")
-            paramCheckOtherMods(sim, "testCommonPar", ifSetButDifferent = "message")
-            paramCheckOtherMods(sim, "testCommonPar", ifSetButDifferent = "silent")
-      }
-      if (isTRUE(!is.null(P(sim)$testRestartSpades))) {
-        stop("testing restartSpades")#browser()
-      }
-
-      mod$a <- 1
-      sim$testPar2 <- Par$testParB
-      sim <- scheduleEvent(sim, start(sim), "test2", "event1", .skipChecks = TRUE)
-      },
-      event1 = {
-      if (isTRUE(P(sim)$testParB >= 1100)) {
-         P(sim, "testParB") <-  P(sim)$testParB + 800
-      }
-      mod$b <- mod$a + 1
-      mod$y <- paste0(mod$y, " is test2")
-      sim <- scheduleEvent(sim, sim@simtimes[["current"]] + 2, "test2", "event1", .skipChecks = TRUE)
-      })
-      return(invisible(sim))
-      }
-      .inputObjects <- function(sim) {
-      if (isTRUE(P(sim)$testParB >= 543)) {
-         P(sim, "testParB") <-  P(sim)$testParB + 654
-      }
-
-      if (isTRUE(P(sim)$testParB > 321321)) {
-         P(sim, "checkpoint")
-      }
-      mod$y <- "This module"
-        return(sim)
-      }
-      ', fill = TRUE)
+  cat(file = test2FilePath, test2Code, fill = TRUE)
 
   mySim <- simInit(times = list(start = 0, end = 0),
                    paths = list(modulePath = tmpdir), modules = c("test", "test2"))
@@ -195,12 +63,12 @@ test_that("local mod object", {
 
   # Cached copy
   expect_true(any(grepl("loaded cached", mess)))
-  expect_true(out4$.mods$test$.objects$a == 2)
-  expect_true(out4$.mods$test2$.objects$a == 1)
-  expect_true(out4$.mods$test2$.objects$b == 2)
+  expect_true(out4$.mods$test$.objects$a == 2) ## TODO: fails (gets NULL)
+  expect_true(out4$.mods$test2$.objects$a == 1) ## TODO: fails (gets NULL)
+  expect_true(out4$.mods$test2$.objects$b == 2) ## TODO: fails (gets NULL)
   expect_true(is.null(out4$.mods$test2$.objects$x))
   expect_true(!is.null(out4$.mods$test$.objects$x)) # was made in .inputObjects, copies fine
-  expect_true(out4$.mods$test2$.objects$y == "This module is test2")
+  expect_true(out4$.mods$test2$.objects$y == "This module is test2") ## TODO: fails (gets 'This module')
 
   # Test P replace method
   mySim3 <- simInit(times = list(start = 0, end = 0),
@@ -254,13 +122,11 @@ test_that("local mod object", {
   # Test restartSpades # The removal of the completed ... it shouldn't, but it did previously
   if (interactive()) {
     opt <- options("spades.recoveryMode" = TRUE)
-    on.exit(opt, add = TRUE)
+    on.exit(options(opt), add = TRUE)
     mySim8 <- simInit(times = list(start = 0, end = 0),
                       paths = list(modulePath = tmpdir), modules = c("test", "test2"),
                       params = list(test2 = list(testRestartSpades = 1)))
-    err <- try({
-      ss <- spades(mySim8, debug = FALSE)
-    }, silent = TRUE)
+    ss <- try(spades(mySim8, debug = FALSE), silent = TRUE)
 
     sim <- asNamespace("SpaDES.core")$.pkgEnv$.sim
     err <- capture_error({
@@ -276,25 +142,64 @@ test_that("local mod object", {
     sim@params$test2$testRestartSpades <- NULL
     sim3 <- restartSpades(sim, debug = FALSE)
     expect_true(NROW(completed(sim3)) == 7)
-    options("spades.recoveryMode" = FALSE)
   }
+})
 
+test_that("convertToPackage testing", {
+  skip_if_not_installed('pkgload')
+  skip_on_cran()
+
+  testInit(c("roxygen2", "ggplot2"), smcc = FALSE, debug = FALSE,
+                          opts = list("reproducible.useMemoise" = FALSE,
+                                      "spades.moduleDocument" = TRUE))
+
+  testName1 <- paste0("test.", .rndstr(len = 2))
+  testName2 <- paste0("test2.", .rndstr(len = 1))
+  mainModFile1 <- paste0(testName1, ".R")
+  mainModFile2 <- paste0(testName2, ".R")
+  try(pkgload::unload(testName1), silent = TRUE)
+  try(pkgload::unload(testName2), silent = TRUE)
+
+  on.exit({
+    try(pkgload::unload(testName1), silent = TRUE)
+    try(pkgload::unload(testName2), silent = TRUE)
+  }, add = TRUE)
+
+  newModule(testName1, tmpdir, open = FALSE)
+  newModule(testName2, tmpdir, open = FALSE)
+  testFilePath <- file.path(tmpdir, testName1, mainModFile1)
+  test2FilePath <- file.path(tmpdir, testName2, mainModFile2)
+
+  # Sept 18 2018 -- Changed to use "seconds" -- better comparison with simple loop
+
+  testCodeMod <- gsub("test", testName1, testCode)
+  test2CodeMod <- gsub("test2", testName2, test2Code)
+
+  cat(file = testFilePath, testCodeMod, fill = TRUE)
+
+  cat(file = test2FilePath, test2CodeMod, fill = TRUE)
   # Test converting these to packages
-  if (interactive()) {
-    if (requireNamespace("pkgload")) {
-      cat(file = testFilePath,'
+  cat(file = testFilePath,'
+      #\' @title Init
+      #\' @rdname Init
+      #\' @name Init
+      #\' @param sim A simList
       Init <- function(sim) {
         sim$aaaa <- Run(1)
         return(sim)
       }
 
+      #\' @title Run
+      #\' @name Run
+      #\' @param a An object
       Run <- function(a) {
         return(a + 1)
       }
       ', fill = TRUE, append = TRUE)
 
-      cat(file = test2FilePath,'
+  cat(file = test2FilePath,'
       Init <- function(sim) {
+        # Need to keep comments
         sim$cccc <- try(Run(1), silent = TRUE)
         return(sim)
       }
@@ -304,55 +209,56 @@ test_that("local mod object", {
       }
       ', fill = TRUE, append = TRUE)
 
-      # aaaaa <<- 1
-
-      for (tt in c("test", "test2")) {
-        expect_true(!file.exists(file.path(tmpdir, tt, "DESCRIPTION")))
-        expect_true(!file.exists(file.path(tmpdir, tt, "NAMESPACE")))
-      }
-      convertToPackage(module = "test", path = tmpdir, buildDocuments = FALSE)
-      convertToPackage(module = "test2", path = tmpdir, buildDocuments = FALSE)
-      for (tt in c("test", "test2")) {
-        expect_true(file.exists(file.path(tmpdir, tt, "DESCRIPTION")))
-        expect_true(!file.exists(file.path(tmpdir, tt, "NAMESPACE")))
-        expect_true(dir.exists(file.path(tmpdir, tt, "R")))
-      }
-      expect_true(file.exists(file.path(tmpdir, "test", "R", "Init.R")))
-      expect_true(file.exists(file.path(tmpdir, "test2", "R", "Init.R")))
-      expect_true(file.exists(file.path(tmpdir, "test", "R", "Run.R")))
-      expect_true(file.exists(file.path(tmpdir, "test2", "R", "Run2.R")))
-
-      mySim9 <- simInit(times = list(start = 0, end = 0),
-                        paths = list(modulePath = tmpdir), modules = c("test", "test2"))
-
-      # doesn't document
-      for (tt in c("test", "test2")) {
-        expect_true(file.exists(file.path(tmpdir, tt, "DESCRIPTION")))
-        expect_true(!file.exists(file.path(tmpdir, tt, "NAMESPACE")))
-        expect_true(dir.exists(file.path(tmpdir, tt, "R")))
-      }
-      working <- spades(mySim9, debug = FALSE)
-
-      # document -- this exports all functions!! Danger for testing later
-      out <- lapply(c("test", "test2"), function(tt) {
-        roxygen2::roxygenise(file.path(tmpdir, tt))
-      })
-
-      # Will run document() so will have the NAMESPACE and
-      for (tt in c("test", "test2")) {
-        expect_true(file.exists(file.path(tmpdir, tt, "DESCRIPTION")))
-        expect_true(file.exists(file.path(tmpdir, tt, "NAMESPACE")))
-        expect_true(sum(grepl("export.+doEvent", readLines(file.path(tmpdir, tt, "NAMESPACE")))) == 1)
-      }
-
-      # check that inheritance is correct -- Run is in the namespace, Init also... doEvent calls Init calls Run
-      expect_true(is(working, "simList"))
-      expect_true(working$aaaa == 2)
-      expect_true(is(working$cccc, "try-error"))
-      bbb <- Run2(2)
-      expect_true(bbb == 4)
-      pkgload::unload("test")
-      pkgload::unload("test2")
-    }
+  for (tt in c(testName1, testName2)) {
+    expect_false(file.exists(file.path(tmpdir, tt, "DESCRIPTION")))
+    expect_false(file.exists(file.path(tmpdir, tt, "NAMESPACE")))
   }
+  convertToPackage(module = testName1, path = tmpdir, buildDocuments = FALSE)
+  convertToPackage(module = testName2, path = tmpdir, buildDocuments = FALSE)
+  for (tt in c(testName1, testName2)) {
+    expect_true(file.exists(file.path(tmpdir, tt, "DESCRIPTION")))
+    expect_true(!file.exists(file.path(tmpdir, tt, "NAMESPACE")))
+    expect_true(dir.exists(file.path(tmpdir, tt, "R")))
+  }
+
+  expect_true(file.exists(file.path(tmpdir, testName1, "R", "Init.R")))
+  expect_true(file.exists(file.path(tmpdir, testName2, "R", "Init.R")))
+  expect_true(file.exists(file.path(tmpdir, testName1, "R", "Run.R")))
+  expect_true(file.exists(file.path(tmpdir, testName2, "R", "Run2.R")))
+
+  mySim9 <- simInit(times = list(start = 0, end = 1),
+                    paths = list(modulePath = tmpdir), modules = c(testName1, testName2))
+
+  # doesn't document, unless it is first time
+  for (tt in c(testName1, testName2)) {
+    expect_true(file.exists(file.path(tmpdir, tt, "DESCRIPTION")))
+    expect_true(file.exists(file.path(tmpdir, tt, "NAMESPACE")))
+    expect_true(dir.exists(file.path(tmpdir, tt, "R")))
+  }
+  working <- spades(mySim9, debug = FALSE)
+
+  # if (requireNamespace("roxygen2")) {
+    # document -- this exports all functions!! Danger for testing later
+    # out <- lapply(c(testName1, testName2), function(tt) {
+    #   roxygen2::roxygenise(file.path(tmpdir, tt))
+    # })
+
+    # Will run document() so will have the NAMESPACE and
+    for (tt in c(testName1, testName2)) {
+      expect_true(file.exists(file.path(tmpdir, tt, "DESCRIPTION")))
+      expect_true(file.exists(file.path(tmpdir, tt, "NAMESPACE")))
+      expect_true(sum(grepl("export.+doEvent", readLines(file.path(tmpdir, tt, "NAMESPACE")))) == 1)
+    }
+
+    # check that inheritance is correct -- Run is in the namespace, Init also... doEvent calls Init calls Run
+    expect_true(is(working, "simList"))
+    expect_true(working$aaaa == 2)
+    expect_true(is(working$cccc, "try-error"))
+    bbb <- get("Run2", asNamespace(testName2))(2)
+    fnTxt <- readLines(file.path(dirname(test2FilePath), "R", "Init.R"))
+    expect_true(sum(grepl("Need to keep comments", fnTxt)) == 1)
+    expect_true(bbb == 4)
+    pkgload::unload(testName1)
+    pkgload::unload(testName2)
+  #}
 })
